@@ -297,7 +297,7 @@ static const SECTION union { const guint8 data[2304]; const double alignment; vo
   0x65, 0x2f, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gcm_resource_data.data, sizeof (gcm_resource_data.data) };
+static GStaticResource static_resource = { gcm_resource_data.data, sizeof (gcm_resource_data.data), NULL, NULL, NULL };
 extern GResource *gcm_get_resource (void);
 GResource *gcm_get_resource (void)
 {
